/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { CommonModule, DatePipe } from "@angular/common";
import { Component, SecurityContext } from "@angular/core";
import { MarkdownComponent, provideMarkdown } from "ngx-markdown";
import { AnnouncementsService } from "../announcements.js";

@Component({
  imports:     [ CommonModule, DatePipe, MarkdownComponent ],
  providers:   [ provideMarkdown({ sanitize: SecurityContext.HTML }) ],
  selector:    "app-announcements",
  styleUrl:    "./announcements.css",
  templateUrl: "./announcements.html",
})
export class Announcements {
  public announcements: Array<{
    title:     string;
    content:   string;
    createdAt: string;
    type:      "products" | "community";
  }> = [];
  public constructor(
    private readonly announcementsService: AnnouncementsService,
  ) {
    void this.loadAnnouncements();
  }

  private async loadAnnouncements(): Promise<void> {
    const announcements = await this.announcementsService.getAnnouncements();
    this.announcements = announcements.sort((a, b) => {
      return b.createdAt > a.createdAt
        ? 1
        : -1;
    });
  }
}
